@@ -1,6 +1,6 @@
 from .aes import InvalidPadding
 from .keys import verify_signed_text, Key, PublicKey, PrivateKey
 from .transaction import TxInput, TxOutput, Transaction, Unspent, InsufficientFunds
-from .wallet import Wallet
+from .wallet import Wallet, WalletLite, create_transaction
 
-__version__ = '0.4.3'
+__version__ = '0.5.0'
