@@ -1,3 +1,3 @@
 from .bip32 import Xkey, Xprv, Xpub, ckd, step_to_index, master_xprv_from_seed
 from .bip39 import WordList, mnemonic_from_entropy, seed_from_mnemonic, validate_mnemonic
-from .bip44 import derive_from_xkey, derive_from_mnemonic
+from .bip44 import derive_xkeys_from_xkey, derive_xprvs_from_mnemonic, derive_xprv_from_mnemonic
